#!/usr/bin/python
# -*- coding: utf-8 -*-
# 必要なライブラリ
import pandas as pd
pd.set_option('display.max_columns', 99999)
pd.set_option('display.max_rows', 500)
import pandas as pd
from pandas import Series, DataFrame
import datetime
from datetime import timedelta

import cgi
import sqlite3
import sys
import json

data = sys.stdin.read()
params = json.loads(data)


df = pd.read_csv('testdata_3.csv', dtype = 'object')
# 属性カラムを判断し左からattr1, attr2, .. と命名
attr_columns = df.columns.drop(['id', 'timestamp', 'area', 'area_lat', 'area_lng', 'value'])
attrs = [] # attr1, attr2, ...→この後の処理に使用 
attrs_name = [] #  csv内のもとの名前→HTML内のフィルターの題名や、属性分析の属性選択リストに使用
for i, column in enumerate(attr_columns):
    df.rename(columns={column: f'attr{i+1}'}, inplace=True)
    attrs.append(f'attr{i+1}')
    attrs_name.append(column)
# 型指定（attr情報はobjectのまま）
df['id'] = df['id'].astype(str)
df['timestamp'] = pd.to_datetime(df['timestamp'])
df['area'] = df['area'].astype(str)
df['area_lat'] = df['area_lat'].astype(float)
df['area_lng'] = df['area_lng'].astype(float)
df['value'] = df['value'].astype(float)
# 時間を持たせる
df['year'] = df['timestamp'].dt.year
df['month'] = df['timestamp'].dt.month
df['date']  = df['timestamp'].dt.day
df['hour']  = df['timestamp'].dt.hour
df['dow'] = df['timestamp'].dt.strftime("%a")
# 平日・休日を作成、祝日は考慮しない(不変でないため)
df.loc[df['dow'].isin(['Mon', 'Tue', 'Wed', 'Thu', 'Fri']), 'holiday'] = '平日'
df.loc[df['dow'].isin(['Sat', 'Sun']), 'holiday'] = '休日'
df['yyyymmdd'] = df['timestamp'].dt.date
df_all = df.copy()

# 移動情報用に変換
df = df_all.copy()
df.sort_values(['timestamp', 'id'], inplace=True)
df.rename(columns={'area': 'origin_area', 'area_lat': 'origin_area_lat', 'area_lng': 'origin_area_lng'}, inplace=True)
df['destination_area'] = df.groupby(['id', 'yyyymmdd'])['origin_area'].shift(1)
df['destination_area_lat'] = df.groupby(['id', 'yyyymmdd'])['origin_area_lat'].shift(1)
df['destination_area_lng'] = df.groupby(['id', 'yyyymmdd'])['origin_area_lng'].shift(1)
# メモ：originとdestinationが同じ時間帯で絞るつまり●時台に移動した人という考え方（←センサー間が遠く1時間で移動できないと集計できない）
# 　　　→　●時台にoriginを離れた人という考え方（←センサー間の距離があっても可能）
# 移動していないデータを削除
df = df[~(df['origin_area']==df['destination_area'])]
df_move = df.copy()

df = df_move.copy()
result = {}
result["area_list"] = list(set([*df.groupby("origin_area").groups]) & set([*df.groupby("destination_area").groups]))
#result["destination_area_list"] = [*df.groupby("destination_area").groups]
result["year_list"] = [*df.groupby("year").groups]
result["month_list"] = [*df.groupby("month").groups]
result["date_list"] = [*df.groupby("date").groups]
result["hour_list"] = [*df.groupby("hour").groups]
result["holiday_list"] = ['平日', '休日']
result["week_list"] = ['Mon', 'Tue', 'Wed','Thu' ,'Fri','Sat','Sun']
for i in range(5):
    if f'attr{i+1}' in df.columns:
        result[f'attr{i+1}_list'] = [*df.groupby(f'attr{i+1}').groups]
    else:
        result[f'attr{i+1}_list'] = ['すべて']
result["attrs_name"] = attrs_name

result["init_year"] = df.at[df.index[0],'year'].astype(str)
result["init_month"] = df.at[df.index[0],'month'].astype(str)

print("Content-type: application/json")
print("\n\n")
print(json.dumps(result))

print('\n')



